# Changes

## 0.1.4

* Repair new command [features#44](https://codeberg.org/helge/fediverse-features/issues/45)
* Add development instructions to README.md [features#43](https://codeberg.org/helge/fediverse-features/issues/43)

## 0.1.3

* Add output to fediverse-features [features#41](https://codeberg.org/helge/fediverse-features/issues/41)
* Display current version on latest subcommand